==> haskell-resource-pool-0.2.3.2-338-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 resource-pool
version:              0.2.3.2
visibility:           public
id:                   resource-pool-0.2.3.2-AKGkuO1f3nA6ZqNk7gzrCs
key:                  resource-pool-0.2.3.2-AKGkuO1f3nA6ZqNk7gzrCs
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://github.com/bos/pool
synopsis:             A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.

category:             Data, Database, Network
abi:                  183af045276e0533f26c1da57a0527fb
exposed:              True
exposed-modules:      Data.Pool
import-dirs:          /usr/lib/ghc-9.4.8/site-local/resource-pool-0.2.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/resource-pool-0.2.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/resource-pool-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-resource-pool
hs-libraries:         HSresource-pool-0.2.3.2-AKGkuO1f3nA6ZqNk7gzrCs
depends:
    base-4.17.2.1 hashable-1.4.4.0-HayYj9uqgN4KUEsvzi6aVt
    monad-control-1.0.3.1-AfMgfenLyH47Kr3EI6EpcX stm-2.5.1.0
    time-1.12.2 transformers-0.5.6.2
    transformers-base-0.4.6-Cgw3YStqXRmJgDLvmJtvt3
    vector-0.13.2.0-KVjnIHG2Fg91rA02TsgQOf

haddock-interfaces:
    /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock

haddock-html:         /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resource-pool-0.2.3.2-341-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 resource-pool
version:              0.2.3.2
visibility:           public
id:                   resource-pool-0.2.3.2-5IRg3hOnRsBImdQcWwydkr
key:                  resource-pool-0.2.3.2-5IRg3hOnRsBImdQcWwydkr
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://github.com/bos/pool
synopsis:             A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.

category:             Data, Database, Network
abi:                  957371960d5a62ea31facff37a65dfe4
exposed:              True
exposed-modules:      Data.Pool
import-dirs:          /usr/lib/ghc-9.4.8/site-local/resource-pool-0.2.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/resource-pool-0.2.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/resource-pool-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-resource-pool
hs-libraries:         HSresource-pool-0.2.3.2-5IRg3hOnRsBImdQcWwydkr
depends:
    base-4.17.2.1 hashable-1.4.4.0-8IAMfvJ5RiNBptVjfaEAIZ
    monad-control-1.0.3.1-9iRK5vogyiY3AykDsFPyv9 stm-2.5.1.0
    time-1.12.2 transformers-0.5.6.2
    transformers-base-0.4.6-4FFK13FM2GI28QxDA2palV
    vector-0.13.2.0-DHb3zbtAYMJG5fP738ULIp

haddock-interfaces:
    /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock

haddock-html:         /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
